@@ -1,9 +1,10 @@
 #![feature(unsize)]
 #![feature(downcast_unchecked)]
 #![feature(box_into_inner)]
+#![feature(coerce_unsized)]
 
-mod dependency_core_context;
-pub (crate) use dependency_core_context::*;
+mod core_context;
+pub (crate) use core_context::*;
 
 mod dependency_context;
 pub use dependency_context::*;
@@ -11,8 +12,8 @@ pub use dependency_context::*;
 mod dependency_type;
 pub use dependency_type::*;
 
-mod dependency_life_cycle;
-pub use dependency_life_cycle::*;
+mod life_cycle;
+pub use life_cycle::*;
 
 mod dependency;
 pub (crate) use dependency::*;
@@ -29,11 +30,19 @@ pub use dependency_builder::*;
 mod dependency_constructor;
 pub use dependency_constructor::*;
 
+pub mod service;
+
+mod cycled_component_builder;
+pub (crate) use cycled_component_builder::*;
+
+mod global_scope;
+pub (crate) use global_scope::*;
+
 mod constructors;
-pub use constructors::*;
+pub (crate) use constructors::*;
 
 pub mod types;
 
-pub mod extensions;
 
+#[cfg(test)]
 pub mod tests;
\ No newline at end of file
