@@ -1,5 +1,4 @@
 use async_trait::async_trait;
-use tokio::sync::RwLock;
 
 use crate::{
     Constructor,
@@ -30,14 +29,15 @@ impl GetStr for ScopedDependency {
 
 #[tokio::test]
 async fn single_scoped_interface() {
-    use crate::DependencyContext;
-    use crate::extensions::InterfaceDependencySetStrategy;
+    use crate::{DependencyContext, DependencyLifeCycle};
     use std::sync::Weak;
+    use tokio::sync::RwLock;
 
     let root_context = DependencyContext::new_root();
-    root_context.set_scoped_interface::<RwLock<dyn GetStr>, RwLock<ScopedDependency>>().await.unwrap();
+    root_context.register_type::<RwLock<ScopedDependency>>(DependencyLifeCycle::Scoped).await.unwrap()
+        .map_as::<RwLock<dyn GetStr>>().await.unwrap();
 
-    let dependency = root_context.get::<Weak<Box<RwLock<dyn GetStr>>>>().await.unwrap();
+    let dependency = root_context.resolve::<Weak<RwLock<dyn GetStr>>>().await.unwrap();
 
     assert_eq!(dependency.upgrade().unwrap().read().await.get(), "test".to_string());
 }
\ No newline at end of file
