@@ -1,5 +1,4 @@
 use async_trait::async_trait;
-use tokio::sync::RwLock;
 
 use crate::{
     Constructor,
@@ -30,14 +29,15 @@ impl GetStr for SingletonDependency {
 
 #[tokio::test]
 async fn single_singleton_interface() {
-    use crate::DependencyContext;
-    use crate::extensions::InterfaceDependencySetStrategy;
+    use crate::{DependencyContext, DependencyLifeCycle};
     use std::sync::Arc;
+    use tokio::sync::RwLock;
 
     let root_context = DependencyContext::new_root();
-    root_context.set_singleton_interface::<RwLock<dyn GetStr>, RwLock<SingletonDependency>>().await.unwrap();
+    root_context.register_type::<RwLock<SingletonDependency>>(DependencyLifeCycle::Singleton).await.unwrap()
+        .map_as::<RwLock<dyn GetStr>>().await.unwrap();
 
-    let dependency = root_context.get::<Arc<Box<RwLock<dyn GetStr>>>>().await.unwrap();
+    let dependency = root_context.resolve::<Arc<RwLock<dyn GetStr>>>().await.unwrap();
 
     assert_eq!(dependency.read().await.get(), "test".to_string());
 }
\ No newline at end of file
