@@ -19,20 +19,33 @@ impl Constructor for TransientDependency {
 
 #[tokio::test]
 async fn single_transient_closure() {
-    use crate::DependencyContext;
-    use crate::extensions::ClosureDependencySetStrategy;
+    use crate::{DependencyContext, DependencyLifeCycle};
 
     let root_context = DependencyContext::new_root();
 
-    root_context.set_transient_closure::<TransientDependency>(
+    root_context.register_closure(|_| Ok(TransientDependency { str: "test".to_string() }), DependencyLifeCycle::Transient).await.unwrap();
+
+    let dependency = root_context.resolve::<TransientDependency>().await.unwrap();
+
+    assert_eq!(dependency.str, "test".to_string());
+}
+
+#[tokio::test]
+async fn single_transient_async_closure() {
+    use crate::{DependencyContext, DependencyLifeCycle};
+
+    let root_context = DependencyContext::new_root();
+
+    root_context.register_async_closure(
         Box::new(move |_: crate::DependencyContext| {
             Box::pin (async move {
                 return Ok(TransientDependency { str: "test".to_string() });
             })
-        })
+        }),
+        DependencyLifeCycle::Transient
     ).await.unwrap();
 
-    let dependency = root_context.get::<TransientDependency>().await.unwrap();
+    let dependency = root_context.resolve::<TransientDependency>().await.unwrap();
 
     assert_eq!(dependency.str, "test".to_string());
 }
\ No newline at end of file
