@@ -29,13 +29,13 @@ impl GetStr for TransientDependency {
 
 #[tokio::test]
 async fn single_transient_interface() {
-    use crate::DependencyContext;
-    use crate::extensions::InterfaceDependencySetStrategy;
+    use crate::{DependencyContext, DependencyLifeCycle};
 
     let root_context = DependencyContext::new_root();
-    root_context.set_transient_interface::<dyn GetStr, TransientDependency>().await.unwrap();
-
-    let dependency = root_context.get::<Box<dyn GetStr>>().await.unwrap();
+    root_context.register_type::<TransientDependency>(DependencyLifeCycle::Transient).await.unwrap()
+        .map_as::<dyn GetStr>().await.unwrap();
+    
+    let dependency = root_context.resolve::<Box<dyn GetStr>>().await.unwrap();
 
     assert_eq!(dependency.get(), "test".to_string());
 }
\ No newline at end of file
